# Generated by Django 5.2.10 on 2026-03-07 23:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_resaas', '0003_alter_layoutsetting_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='entidade',
            name='site',
            field=models.CharField(default='-', max_length=300, null=True),
        ),
    ]
